@@ -202,6 +202,12 @@ class DocParser:
         Parses document using TIKA (for everything) and FaceAnalyzer (for images).
         """
         output_document = {}
+        tika_options = {
+            "headers": {
+                "X-Tika-OCRLanguage": "+".join(languages),
+                "X-Tika-PDFextractInlineImages": "true"
+            }
+        }
         # extract faces if an image
         if document["extension"] in Extension.IMAGE_EXTENSIONS:
             # import here so we won't die on init if analyzer not installed
@@ -210,7 +216,7 @@ class DocParser:
             if face_vectors:
                 output_document[FACE_VECTOR_FIELD_NAME] = [{"name": "UNKOWN_FACE", "vector": v} for v in face_vectors]
         # extract text using TIKA
-        tika_output = parser.from_file(document["path"], requestOptions={"headers": {"X-Tika-OCRLanguage": "+".join(languages)}})
+        tika_output = parser.from_file(document["path"], requestOptions=tika_options)
         content = tika_output["content"]
         if content != None:  # remove leading and trailing spacing
             lines = (line.strip() for line in content.splitlines())
